@@ -28,7 +28,7 @@ our %FIXED_ATTRIBUTE_NAMES = (
   Note          => 99,
 );
 
-our $VERSION = '0.081'; # VERSION
+our $VERSION = '0.082'; # VERSION
 
 extends 'Bio::Gonzales::MiniFeat';
 
@@ -116,8 +116,8 @@ sub to_gff3 {
   }
 
   return join( "\t",
-    $self->seq_id, $self->source, $self->type,
-    $self->start,  $self->end,    $self->score // '.',
+    $self->seq_id, $self->source // '.', $self->type,
+    $self->start, $self->end, $self->score // '.',
     $strand, $self->phase // '.', join( ';', @groups ) )
     . "\n";
 }
